@@ -1,8 +1,3 @@
-import os
-import tempfile
-import webbrowser
-
-
 class DriverAPI(object):
     @property
     def title(self):
@@ -25,15 +20,6 @@ class DriverAPI(object):
     def evaluate_script(self, script):
         raise NotImplementedError
 
-    def open_in_browser(self, path):
-        webbrowser.open(path)
-        
-    def save_and_open_page(self):
-        filepath = tempfile.mktemp(prefix='splinter')
-        with open(filepath, 'w') as temp:
-            temp.write(self.html)
-        self.open_in_browser(filepath)
-         
     def find_by_css_selector(self, css_selector):
         raise NotImplementedError
         
@@ -57,8 +43,9 @@ class DriverAPI(object):
 
     def fill_in(self, name, value):
         raise NotImplementedError
-        
-    attach_file = fill_in
+
+    fill = fill_in
+    attach_file = fill
 
     def choose(self, name):
         raise NotImplementedError
