@@ -1,7 +1,10 @@
 from flask import Flask
 from flask import request
+from multiprocessing import Process
+from urllib import urlopen
+
+EXAMPLE_APP = "http://localhost:5000/"
 
-EXAMPLE_APP = 'http://localhost:5000/'
 EXAMPLE_HTML = """\
 <html>
   <head>
@@ -10,21 +13,29 @@ EXAMPLE_HTML = """\
   </head>
   <body>
     <h1 id="firstheader">Example Header</h1>
+    <h1 id="firstheader">Example Last Header</h1>
     <form action="name" method="GET">
         <label for="query">Query</label>
         <input type="text" name="query" value="default value" />
+        <input type="text" name="query" value="default last value" />
         <label for="send">Send</label>
         <input type="submit" name="send" />
         <input type="radio" name="some-radio" value="choice" />
         <input type="radio" name="other-radio" value="other-choice" />
         <input type="checkbox" name="some-check" value="choice" />
         <input type="checkbox" name="checked-checkbox" value="choosed" checked="checked" />
+        <select name="uf">
+            <option value="mt">Mato Grosso</option>
+            <option value="rj">Rio de Janeiro</option>
+        </select>
     </form>
     <form action="/upload" method="POST" enctype="multipart/form-data">
         <input type="file" name="file"> 
         <input type="submit" name="upload" />
     </form>
     <a href="http://example.com">Link for Example.com</a>
+    <a href="http://example.com/last">Link for Example.com</a>
+    <a href="http://example.com">Link for last Example.com</a>
     <div id="visible">visible</div>
     <div id="invisible" style="display:none">invisible</div>
     <a href="/foo">FOO</a>
@@ -55,8 +66,43 @@ def upload_file():
 def foo():
     return "BAR!"
 
-if __name__ == '__main__':
-    import logging
-    logging.disable(logging.CRITICAL)
+class Env(object):
+    pass
 
-    app.run()
+env = Env()
+env.process = None
+env.host, env.port = 'localhost', 5000
+env.browser = None
+
+def start_flask_app(host, port):
+    """Runs the server."""
+    app.run(host=host, port=port)
+    app.config['DEBUG'] = False
+    app.config['TESTING'] = False
+
+def wait_until_start():
+    while True:
+        try:
+            urlopen(EXAMPLE_APP)
+            break
+        except IOError:
+            pass
+
+def wait_until_stop():
+    while True:
+        try:
+            results = urlopen(EXAMPLE_APP)
+            if results.code == 404:
+                break
+        except IOError:
+            break
+
+def start_server():
+    env.process = Process(target=start_flask_app, args=(env.host, env.port))
+    env.process.daemon = True
+    env.process.start()
+    wait_until_start()
+
+def stop_server():
+    env.process.terminate()
+    wait_until_stop()
